# eric7.Plugins.WizardPlugins

Package containing the various core wizard plugins.

### Packages

ColorDialogWizard | Package implementing the color dialog wizard.
DotDesktopWizard | Package implementing the .desktop wizard plug-in data and dialog.
EricMessageBoxWizard | Package implementing the eric message box wizard.
EricPluginWizard | Package implementing the eric plug-in wizard dialog and data.
FileDialogWizard | Package implementing the file dialog wizard.
FontDialogWizard | Package implementing the font dialog wizard.
InputDialogWizard | Package implementing the input dialog wizard.
MessageBoxWizard | Package implementing the message box wizard.
PyRegExpWizard | Package implementing the Python re wizard.
QRegularExpressionWizard | Package implementing the QRegularExpression wizard.
SetupWizard | Package implementing the setup.py wizard dialog.